pub struct CreateUserOAuthLinkOptions {
pub user_uuid: Uuid,
pub oauth_provider_uuid: Uuid,
pub identifier: CompactString,
}Fields
user_uuid: Uuidoauth_provider_uuid: Uuididentifier: CompactStringTrait Implementations
Sourceimpl ComposeSchema for CreateUserOAuthLinkOptions
impl ComposeSchema for CreateUserOAuthLinkOptions
Sourceimpl<'de> Deserialize<'de> for CreateUserOAuthLinkOptions
impl<'de> Deserialize<'de> for CreateUserOAuthLinkOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateUserOAuthLinkOptions
impl ToSchema for CreateUserOAuthLinkOptions
Sourceimpl Validate for CreateUserOAuthLinkOptions
impl Validate for CreateUserOAuthLinkOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateUserOAuthLinkOptions
impl RefUnwindSafe for CreateUserOAuthLinkOptions
impl Send for CreateUserOAuthLinkOptions
impl Sync for CreateUserOAuthLinkOptions
impl Unpin for CreateUserOAuthLinkOptions
impl UnwindSafe for CreateUserOAuthLinkOptions